@@ -3,7 +3,7 @@
 ;; Customize                                                                  ;;
 ;;----------------------------------------------------------------------------;;
 
-(require 'cl)
+(eval-when-compile (require 'cl))
 (require 'custom)
 
 (defgroup tuareg2 nil
@@ -2351,7 +2351,7 @@ Known bugs:
 Short cuts for the Tuareg2 mode:
 \\{tuareg2-mode-map}
 
-Short cuts for interactions with the toplevel:
+Short cuts for interactions with the REPL:
 \\{tuareg2-interactive-mode-map}"
   (interactive)
   (kill-all-local-variables)
@@ -2365,7 +2365,7 @@ Short cuts for interactions with the toplevel:
   (make-local-variable 'paragraph-separate)
   (setq paragraph-separate paragraph-start)
   (make-local-variable 'require-final-newline)
-  (setq require-final-newline t)
+  (setq require-final-newline mode-require-final-newline)
   (make-local-variable 'comment-start)
   (setq comment-start "(* ")
   (make-local-variable 'comment-end)
